==> pmml-model-gwt-1.3.9-sources.jar: org/dmg/pmml/time_series/TimeAnchor.java <==

package org.dmg.pmml.time_series;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.Property;
import org.jpmml.schema.Added;
import org.jpmml.schema.Version;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_3}TimeCycle" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_3}TimeException" maxOccurs="2" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="type">
 *         &lt;simpleType>
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *             &lt;enumeration value="dateTimeMillisecondsSince[0]"/>
 *             &lt;enumeration value="dateTimeMillisecondsSince[1960]"/>
 *             &lt;enumeration value="dateTimeMillisecondsSince[1970]"/>
 *             &lt;enumeration value="dateTimeMillisecondsSince[1980]"/>
 *             &lt;enumeration value="dateTimeSecondsSince[0]"/>
 *             &lt;enumeration value="dateTimeSecondsSince[1960]"/>
 *             &lt;enumeration value="dateTimeSecondsSince[1970]"/>
 *             &lt;enumeration value="dateTimeSecondsSince[1980]"/>
 *             &lt;enumeration value="dateDaysSince[0]"/>
 *             &lt;enumeration value="dateDaysSince[1960]"/>
 *             &lt;enumeration value="dateDaysSince[1970]"/>
 *             &lt;enumeration value="dateDaysSince[1980]"/>
 *             &lt;enumeration value="dateMonthsSince[0]"/>
 *             &lt;enumeration value="dateMonthsSince[1960]"/>
 *             &lt;enumeration value="dateMonthsSince[1970]"/>
 *             &lt;enumeration value="dateMonthsSince[1980]"/>
 *             &lt;enumeration value="dateYearsSince[0]"/>
 *           &lt;/restriction>
 *         &lt;/simpleType>
 *       &lt;/attribute>
 *       &lt;attribute name="offset" type="{http://www.dmg.org/PMML-4_3}INT-NUMBER" />
 *       &lt;attribute name="stepsize" type="{http://www.dmg.org/PMML-4_3}INT-NUMBER" />
 *       &lt;attribute name="displayName" type="{http://www.w3.org/2001/XMLSchema}anySimpleType" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "timeCycles",
    "timeExceptions"
})
@XmlRootElement(name = "TimeAnchor", namespace = "http://www.dmg.org/PMML-4_3")
@Added(Version.PMML_4_0)
public class TimeAnchor
    extends org.dmg.pmml.PMMLObject
{

    @XmlAttribute(name = "type")
    private TimeAnchor.Type type;
    @XmlAttribute(name = "offset")
    private Integer offset;
    @XmlAttribute(name = "stepsize")
    private Integer stepsize;
    @XmlAttribute(name = "displayName")
    @XmlSchemaType(name = "anySimpleType")
    private String displayName;
    @XmlElement(name = "TimeCycle", namespace = "http://www.dmg.org/PMML-4_3")
    private List<TimeCycle> timeCycles;
    @XmlElement(name = "TimeException", namespace = "http://www.dmg.org/PMML-4_3")
    private List<TimeException> timeExceptions;
    private final static long serialVersionUID = 67305479L;

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link TimeAnchor.Type }
     *     
     */
    public TimeAnchor.Type getType() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param type
     *     allowed object is
     *     {@link TimeAnchor.Type }
     *     
     */
    public TimeAnchor setType(
        @Property("type")
        TimeAnchor.Type type) {
        this.type = type;
        return this;
    }

    /**
     * Gets the value of the offset property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getOffset() {
        return offset;
    }

    /**
     * Sets the value of the offset property.
     * 
     * @param offset
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public TimeAnchor setOffset(
        @Property("offset")
        Integer offset) {
        this.offset = offset;
        return this;
    }

    /**
     * Gets the value of the stepsize property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getStepsize() {
        return stepsize;
    }

    /**
     * Sets the value of the stepsize property.
     * 
     * @param stepsize
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public TimeAnchor setStepsize(
        @Property("stepsize")
        Integer stepsize) {
        this.stepsize = stepsize;
        return this;
    }

    /**
     * Gets the value of the displayName property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDisplayName() {
        return displayName;
    }

    /**
     * Sets the value of the displayName property.
     * 
     * @param displayName
     *     allowed object is
     *     {@link String }
     *     
     */
    public TimeAnchor setDisplayName(
        @Property("displayName")
        String displayName) {
        this.displayName = displayName;
        return this;
    }

    /**
     * Gets the value of the timeCycles property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the timeCycles property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTimeCycles().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TimeCycle }
     * 
     * 
     */
    public List<TimeCycle> getTimeCycles() {
        if (timeCycles == null) {
            timeCycles = new ArrayList<TimeCycle>();
        }
        return this.timeCycles;
    }

    /**
     * Gets the value of the timeExceptions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the timeExceptions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTimeExceptions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link TimeException }
     * 
     * 
     */
    public List<TimeException> getTimeExceptions() {
        if (timeExceptions == null) {
            timeExceptions = new ArrayList<TimeException>();
        }
        return this.timeExceptions;
    }

    public boolean hasTimeCycles() {
        return ((this.timeCycles!= null)&&(this.timeCycles.size()> 0));
    }

    public TimeAnchor addTimeCycles(TimeCycle... timeCycles) {
        getTimeCycles().addAll(Arrays.asList(timeCycles));
        return this;
    }

    public boolean hasTimeExceptions() {
        return ((this.timeExceptions!= null)&&(this.timeExceptions.size()> 0));
    }

    public TimeAnchor addTimeExceptions(TimeException... timeExceptions) {
        getTimeExceptions().addAll(Arrays.asList(timeExceptions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasTimeCycles()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getTimeCycles());
            }
            if ((status == VisitorAction.CONTINUE)&&hasTimeExceptions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getTimeExceptions());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }


    /**
     * <p>Java class for null.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * <p>
     * <pre>
     * &lt;simpleType>
     *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
     *     &lt;enumeration value="dateTimeMillisecondsSince[0]"/>
     *     &lt;enumeration value="dateTimeMillisecondsSince[1960]"/>
     *     &lt;enumeration value="dateTimeMillisecondsSince[1970]"/>
     *     &lt;enumeration value="dateTimeMillisecondsSince[1980]"/>
     *     &lt;enumeration value="dateTimeSecondsSince[0]"/>
     *     &lt;enumeration value="dateTimeSecondsSince[1960]"/>
     *     &lt;enumeration value="dateTimeSecondsSince[1970]"/>
     *     &lt;enumeration value="dateTimeSecondsSince[1980]"/>
     *     &lt;enumeration value="dateDaysSince[0]"/>
     *     &lt;enumeration value="dateDaysSince[1960]"/>
     *     &lt;enumeration value="dateDaysSince[1970]"/>
     *     &lt;enumeration value="dateDaysSince[1980]"/>
     *     &lt;enumeration value="dateMonthsSince[0]"/>
     *     &lt;enumeration value="dateMonthsSince[1960]"/>
     *     &lt;enumeration value="dateMonthsSince[1970]"/>
     *     &lt;enumeration value="dateMonthsSince[1980]"/>
     *     &lt;enumeration value="dateYearsSince[0]"/>
     *   &lt;/restriction>
     * &lt;/simpleType>
     * </pre>
     * 
     */
    @XmlType(name = "")
    @XmlEnum
    @Added(Version.PMML_4_0)
    public enum Type {

        @XmlEnumValue("dateTimeMillisecondsSince[0]")
        DATE_TIME_MILLISECONDS_SINCE_0("dateTimeMillisecondsSince[0]"),
        @XmlEnumValue("dateTimeMillisecondsSince[1960]")
        DATE_TIME_MILLISECONDS_SINCE_1960("dateTimeMillisecondsSince[1960]"),
        @XmlEnumValue("dateTimeMillisecondsSince[1970]")
        DATE_TIME_MILLISECONDS_SINCE_1970("dateTimeMillisecondsSince[1970]"),
        @XmlEnumValue("dateTimeMillisecondsSince[1980]")
        DATE_TIME_MILLISECONDS_SINCE_1980("dateTimeMillisecondsSince[1980]"),
        @XmlEnumValue("dateTimeSecondsSince[0]")
        DATE_TIME_SECONDS_SINCE_0("dateTimeSecondsSince[0]"),
        @XmlEnumValue("dateTimeSecondsSince[1960]")
        DATE_TIME_SECONDS_SINCE_1960("dateTimeSecondsSince[1960]"),
        @XmlEnumValue("dateTimeSecondsSince[1970]")
        DATE_TIME_SECONDS_SINCE_1970("dateTimeSecondsSince[1970]"),
        @XmlEnumValue("dateTimeSecondsSince[1980]")
        DATE_TIME_SECONDS_SINCE_1980("dateTimeSecondsSince[1980]"),
        @XmlEnumValue("dateDaysSince[0]")
        DATE_DAYS_SINCE_0("dateDaysSince[0]"),
        @XmlEnumValue("dateDaysSince[1960]")
        DATE_DAYS_SINCE_1960("dateDaysSince[1960]"),
        @XmlEnumValue("dateDaysSince[1970]")
        DATE_DAYS_SINCE_1970("dateDaysSince[1970]"),
        @XmlEnumValue("dateDaysSince[1980]")
        DATE_DAYS_SINCE_1980("dateDaysSince[1980]"),
        @XmlEnumValue("dateMonthsSince[0]")
        DATE_MONTHS_SINCE_0("dateMonthsSince[0]"),
        @XmlEnumValue("dateMonthsSince[1960]")
        DATE_MONTHS_SINCE_1960("dateMonthsSince[1960]"),
        @XmlEnumValue("dateMonthsSince[1970]")
        DATE_MONTHS_SINCE_1970("dateMonthsSince[1970]"),
        @XmlEnumValue("dateMonthsSince[1980]")
        DATE_MONTHS_SINCE_1980("dateMonthsSince[1980]"),
        @XmlEnumValue("dateYearsSince[0]")
        DATE_YEARS_SINCE_0("dateYearsSince[0]");
        private final String value;

        Type(String v) {
            value = v;
        }

        public String value() {
            return value;
        }

        public static TimeAnchor.Type fromValue(String v) {
            for (TimeAnchor.Type c: TimeAnchor.Type.values()) {
                if (c.value.equals(v)) {
                    return c;
                }
            }
            throw new IllegalArgumentException(v);
        }

    }

}

==> pmml-model-gwt-1.4.9-sources.jar: org/dmg/pmml/time_series/TimeAnchor.java <==

package org.dmg.pmml.time_series;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import org.dmg.pmml.HasDisplayName;
import org.dmg.pmml.StringValue;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.annotations.Added;
import org.jpmml.model.annotations.Property;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "timeCycles",
    "timeExceptions"
})
@XmlRootElement(name = "TimeAnchor", namespace = "http://www.dmg.org/PMML-4_3")
@Added((org.dmg.pmml.Version.PMML_4_0))
@JsonAutoDetect(fieldVisibility = JsonAutoDetect.Visibility.ANY, getterVisibility = JsonAutoDetect.Visibility.NONE, isGetterVisibility = JsonAutoDetect.Visibility.NONE, setterVisibility = JsonAutoDetect.Visibility.NONE)
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonPropertyOrder({
    "type",
    "offset",
    "stepsize",
    "displayName",
    "timeCycles",
    "timeExceptions"
})
public class TimeAnchor
    extends org.dmg.pmml.PMMLObject
    implements HasDisplayName<TimeAnchor>
{

    @XmlAttribute(name = "type")
    @JsonProperty("type")
    private TimeAnchor.Type type;
    @XmlAttribute(name = "offset")
    @JsonProperty("offset")
    private Integer offset;
    @XmlAttribute(name = "stepsize")
    @JsonProperty("stepsize")
    private Integer stepsize;
    @XmlAttribute(name = "displayName")
    @JsonProperty("displayName")
    private String displayName;
    @XmlElement(name = "TimeCycle", namespace = "http://www.dmg.org/PMML-4_3")
    @JsonProperty("TimeCycle")
    private List<TimeCycle> timeCycles;
    @XmlElement(name = "TimeException", namespace = "http://www.dmg.org/PMML-4_3")
    @JsonProperty("TimeException")
    private List<TimeException> timeExceptions;
    private final static long serialVersionUID = 67305486L;

    public TimeAnchor.Type getType() {
        return type;
    }

    public TimeAnchor setType(
        @Property("type")
        TimeAnchor.Type type) {
        this.type = type;
        return this;
    }

    public Integer getOffset() {
        return offset;
    }

    public TimeAnchor setOffset(
        @Property("offset")
        Integer offset) {
        this.offset = offset;
        return this;
    }

    public Integer getStepsize() {
        return stepsize;
    }

    public TimeAnchor setStepsize(
        @Property("stepsize")
        Integer stepsize) {
        this.stepsize = stepsize;
        return this;
    }

    @Override
    public String getDisplayName() {
        return displayName;
    }

    @Override
    public TimeAnchor setDisplayName(
        @Property("displayName")
        String displayName) {
        this.displayName = displayName;
        return this;
    }

    public boolean hasTimeCycles() {
        return ((this.timeCycles!= null)&&(this.timeCycles.size()> 0));
    }

    public List<TimeCycle> getTimeCycles() {
        if (timeCycles == null) {
            timeCycles = new ArrayList<TimeCycle>();
        }
        return this.timeCycles;
    }

    public TimeAnchor addTimeCycles(TimeCycle... timeCycles) {
        getTimeCycles().addAll(Arrays.asList(timeCycles));
        return this;
    }

    public boolean hasTimeExceptions() {
        return ((this.timeExceptions!= null)&&(this.timeExceptions.size()> 0));
    }

    public List<TimeException> getTimeExceptions() {
        if (timeExceptions == null) {
            timeExceptions = new ArrayList<TimeException>();
        }
        return this.timeExceptions;
    }

    public TimeAnchor addTimeExceptions(TimeException... timeExceptions) {
        getTimeExceptions().addAll(Arrays.asList(timeExceptions));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasTimeCycles()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getTimeCycles());
            }
            if ((status == VisitorAction.CONTINUE)&&hasTimeExceptions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getTimeExceptions());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

    @XmlType(name = "")
    @XmlEnum
    public enum Type
        implements StringValue<TimeAnchor.Type>
    {

        @XmlEnumValue("dateTimeMillisecondsSince[0]")
        @JsonProperty("dateTimeMillisecondsSince[0]")
        DATE_TIME_MILLISECONDS_SINCE_0("dateTimeMillisecondsSince[0]"),
        @XmlEnumValue("dateTimeMillisecondsSince[1960]")
        @JsonProperty("dateTimeMillisecondsSince[1960]")
        DATE_TIME_MILLISECONDS_SINCE_1960("dateTimeMillisecondsSince[1960]"),
        @XmlEnumValue("dateTimeMillisecondsSince[1970]")
        @JsonProperty("dateTimeMillisecondsSince[1970]")
        DATE_TIME_MILLISECONDS_SINCE_1970("dateTimeMillisecondsSince[1970]"),
        @XmlEnumValue("dateTimeMillisecondsSince[1980]")
        @JsonProperty("dateTimeMillisecondsSince[1980]")
        DATE_TIME_MILLISECONDS_SINCE_1980("dateTimeMillisecondsSince[1980]"),
        @XmlEnumValue("dateTimeSecondsSince[0]")
        @JsonProperty("dateTimeSecondsSince[0]")
        DATE_TIME_SECONDS_SINCE_0("dateTimeSecondsSince[0]"),
        @XmlEnumValue("dateTimeSecondsSince[1960]")
        @JsonProperty("dateTimeSecondsSince[1960]")
        DATE_TIME_SECONDS_SINCE_1960("dateTimeSecondsSince[1960]"),
        @XmlEnumValue("dateTimeSecondsSince[1970]")
        @JsonProperty("dateTimeSecondsSince[1970]")
        DATE_TIME_SECONDS_SINCE_1970("dateTimeSecondsSince[1970]"),
        @XmlEnumValue("dateTimeSecondsSince[1980]")
        @JsonProperty("dateTimeSecondsSince[1980]")
        DATE_TIME_SECONDS_SINCE_1980("dateTimeSecondsSince[1980]"),
        @XmlEnumValue("dateDaysSince[0]")
        @JsonProperty("dateDaysSince[0]")
        DATE_DAYS_SINCE_0("dateDaysSince[0]"),
        @XmlEnumValue("dateDaysSince[1960]")
        @JsonProperty("dateDaysSince[1960]")
        DATE_DAYS_SINCE_1960("dateDaysSince[1960]"),
        @XmlEnumValue("dateDaysSince[1970]")
        @JsonProperty("dateDaysSince[1970]")
        DATE_DAYS_SINCE_1970("dateDaysSince[1970]"),
        @XmlEnumValue("dateDaysSince[1980]")
        @JsonProperty("dateDaysSince[1980]")
        DATE_DAYS_SINCE_1980("dateDaysSince[1980]"),
        @XmlEnumValue("dateMonthsSince[0]")
        @JsonProperty("dateMonthsSince[0]")
        DATE_MONTHS_SINCE_0("dateMonthsSince[0]"),
        @XmlEnumValue("dateMonthsSince[1960]")
        @JsonProperty("dateMonthsSince[1960]")
        DATE_MONTHS_SINCE_1960("dateMonthsSince[1960]"),
        @XmlEnumValue("dateMonthsSince[1970]")
        @JsonProperty("dateMonthsSince[1970]")
        DATE_MONTHS_SINCE_1970("dateMonthsSince[1970]"),
        @XmlEnumValue("dateMonthsSince[1980]")
        @JsonProperty("dateMonthsSince[1980]")
        DATE_MONTHS_SINCE_1980("dateMonthsSince[1980]"),
        @XmlEnumValue("dateYearsSince[0]")
        @JsonProperty("dateYearsSince[0]")
        DATE_YEARS_SINCE_0("dateYearsSince[0]");
        private final String value;

        Type(String v) {
            value = v;
        }

        @Override
        public String value() {
            return value;
        }

        public static TimeAnchor.Type fromValue(String v) {
            for (TimeAnchor.Type c: TimeAnchor.Type.values()) {
                if (c.value.equals(v)) {
                    return c;
                }
            }
            throw new IllegalArgumentException(v);
        }

        @Override
        public String toString() {
            return value();
        }

    }

}
